#ifndef NT2_INCLUDE_FUNCTIONS_ISTRIU_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISTRIU_HPP_INCLUDED

#include <nt2/predicates/include/functions/istriu.hpp>

#endif
